/*
 * CustomLoggerFactory.java
 *
 * Created on 16 May 2009
 *
 * Version 1.0
 *
 * Copyright (c) 2009 Kieran Greer
 *
 */


package org.jlog2;


import org.jlog2.util.LogConst;

import java.util.*;


/**
 * This class is an implementation of the logger factory to return the default
 * logger functionality. You can implement your own version instead.
 * @author Kieran Greer
 */
public class CustomLoggerFactory extends LoggerFactory
{
    /**
     * Creates a new instance of CustomLoggerFactory.
     * @throws java.lang.Exception any error.
     */
    public CustomLoggerFactory() throws Exception
    {
        super();
    }

    /**
     * Create a new instance of Logger. Every call creates a new instance,
     * but the channels to write the messages to might be duplicated.
     * @param loggerID the id to identify one logger from another.
     * @return the newly created logger. 
     */
    public Logger getLoggerInstance(String loggerID)
    {
        Logger newLogger;                   //the new logger
        
        newLogger = new Logger(loggerID);
        newLogger.addLogChannels(getLogChannels(loggerID));
        newLogger.addLogChannels(getDefaultLogChannels());
        newLogger.addDebugChannels(getDebugChannels(loggerID));
        newLogger.addDebugChannels(getDefaultDebugChannels());

        return newLogger;
    }

    /**
     * Create and store any new log channels associated with the new log id.
     * @param loggerID the id to identify one logger from another.
     * @return a list of all log channels associated with the logger.
     * This default implementation only adds the default channels created
     * at initialisation time for all loggers.
     */
    protected Vector getLogChannels(String loggerID)
    {
        Vector loggerChannels;                      //the logger channels

        loggerChannels = new Vector();

        if (logChannels.containsKey(LogConst.STDOUTID))
            loggerChannels.addElement(logChannels.get(LogConst.STDOUTID));

        if (logChannels.containsKey(LogConst.STDERRID))
            loggerChannels.addElement(logChannels.get(LogConst.STDERRID));

        if (logChannels.containsKey(LogConst.STDFILEID))
            loggerChannels.addElement(logChannels.get(LogConst.STDFILEID));

        return loggerChannels;
    }

    /**
     * Create and store any new debug channels associated with the new log id.
     * @param loggerID the id to identify one logger from another.
     * @return a list of all debug channels associated with the logger.
     * This default implementation only adds the default channels created
     * at initialisation time for all loggers.
     */
    protected Vector getDebugChannels(String loggerID)
    {
        Vector loggerChannels;                      //the logger channels

        loggerChannels = new Vector();

        if (debugChannels.containsKey(LogConst.STDOUTID))
            loggerChannels.addElement(debugChannels.get(LogConst.STDOUTID));

        if (debugChannels.containsKey(LogConst.STDERRID))
            loggerChannels.addElement(debugChannels.get(LogConst.STDERRID));

        if (debugChannels.containsKey(LogConst.STDFILEID))
            loggerChannels.addElement(debugChannels.get(LogConst.STDFILEID));

        return loggerChannels;
    }
}
